FFTW 3.3.4: FFTW MPI Transposes

Next: FFTW MPI Wisdom, Previous: Other Multi-dimensional Real-data MPI Transforms, Up: Distributed-memory FFTW with MPI [Contents][Index]

### 6.7 FFTW MPI Transposes

The FFTW’s MPI Fourier transforms rely on one or more global transposition step for their communications. For example, the multidimensional transforms work by transforming along some dimensions, then transposing to make the first dimension local and transforming that, then transposing back. Because global transposition of a block-distributed matrix has many other potential uses besides FFTs, FFTW’s transpose routines can be called directly, as documented in this section.